==> larus_board-1.1.0.zip: larus_board-1.1.0/lb_private/lang/de/post.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'back_to_edit_form'=>'Zurück zum Änderungsformular',
'bbcode_button_anchor'=>'Du kannst einen Anker in deinem Beitrag setzen und diesen verlinken',
'bbcode_button_bold'=>'Wähle den Text aus und klicke hier, um ihn fett zu machen',
'bbcode_button_code'=>'Wähle den Text aus und klicke hier, um ihn als Quellcode zu markieren',
'bbcode_button_embed'=>'Klicke hier, um eine externe URL einzubetten (häufig Multimedia)',
'bbcode_button_format'=>'Klicke hier, wähle dann deinen Text aus und weise ihm Spezialformatierungen zu',
'bbcode_button_img'=>'Klicke hier, um ein externes Bild einzufügen',
'bbcode_button_italic'=>'Wähle den Text aus und klicke hier, um ihn kursiv zu setzen',
'bbcode_button_link'=>'Mit dieser Option kannst du einen anderen Beitrag verlinken oder einen deiner Anker',
'bbcode_button_mail'=>'Klicke hier, um eine E-Mail Adresse anzugeben',
'bbcode_button_notice'=>'Priviligierte Benutzer können einen Absatz hervorheben',
'bbcode_button_quote'=>'Wähle den Text aus und klicke hier, um ihn als Zitat zu markieren.',
'bbcode_button_strikethrough'=>'Wähle den Text aus und klicke hier, um ihn durchzustreichen',
'bbcode_button_underline'=>'Wähle den Text aus und klicke hier, um ihn zu unterstreichen',
'bbcode_button_url'=>'Klicke hier, um eine externe URL anzulegen',
'cannot_reply_as_topic_is_closed'=>'Du kannst nicht auf ein geschlossenes Thema antworten!',
'compare_posts'=>'Beiträge vergleichen',
'compare_selected_revisions'=>'Ausgewählte Revisionen vergleichen',
'current_revision'=>'Aktuelle Version',
'edited_because'=>'Wurde geändert wegen',
'edit_posting'=>'Beitrag ändern',
'explain_message'=>'Deine Nachricht enthält den eigentlichen Text. Hier kannst du diskutieren, antworten, fragen und alles andere.',
'explain_post_acl'=>'Du kannst dem Thema eine Zugriffsbeschränkung auferlegen. Nur Benutzer, die den Regeln entsprechen, können dieses lesen.',
'explain_post_user'=>'Du kannst den Benutzernamen des Beitrages anpassen.',
'explain_post_weight'=>'Je höher das "Gewicht" des Beitrages ist, desto eher wird er gelistet. Deine höchste Einstellung wird durch deine Benutzergruppe vorgegeben.',
'explain_reason'=>'Du kannst hier die Gründe angeben warum du den Beitrag geändert hast. Halte ihn kurz und knackig.',
'explain_subject'=>'Ein Betreff fasst dein Anliegen in wenigen Worten zusammen. Falls Präfixe vorhanden sind, kannst du ihn damit fluggs einer Kategorie zuweisen.',
'explain_tags'=>'Du kannst einem Beitrag Stichwörter zuweisen, um diesen zu beschreiben. Diese werden benutzt, um Beiträge zu gruppieren, welche dieselben aufweisen und so ein einfaches Auffinden ermöglichen. Trenne mehrere Wörter mit einem Komma. Schreibst du zum Beispiel über köstliche Bananen, kannst du die Stichwörter "banane,lecker,frucht,essen" benutzen.',
'is_approved_by_default'=>'Der Beitrag ist standardmäßig sofort sichtbar.',
'is_hidden_by_default'=>'Der Beitrag benötigt eine Freigabe bevor er sichtbar wird.',
'listing_all_previous_versions'=>'Dies sind die vergangenen Versionen des Beitrages',
'new_reply'=>'Neue Antwort',
'new_reply_successfully_posted'=>'Deine Antwort wurde dem Thema hinzugefügt.',
'new_topic'=>'Neues Thema',
'new_topic_successfully_posted'=>'Dein Thema wurde dem Forum hinzugefügt.',
'not_allowed_to_access_the_topic'=>'Du hast keinen Zugriff auf das Thema, dem du antworten möchtest!',
'not_allowed_to_submit_repeated_posting'=>'Du kannst keinen weiteren Beitrag schreiben, da der letzte bereits von dir ist!',
'posting_has_been_deleted'=>'Dieser Beitrag wurde gelöscht.',
'posting_has_been_edited'=>'Dieser Beitrag wurde geändert.',
'post_acl'=>'Zugriffsbeschränkung',
'post_source'=>'Quell-Beitrag',
'post_target'=>'Ziel-Beitrag',
'post_weight'=>'Gewicht',
'quote_hint'=>'Falls du eine Nachricht zitierst, bitte beschränke dich auf das wesentliche.',
'rate_disallowed_by_being_too_quiet'=>'Du darfst noch keine Beiträge bewerten, da du selber zu wenige verfasst hast!',
'rate_disallowed_by_short_membership'=>'Du darfst noch keine Beiträge bewerten, da du noch nicht lange genug Mitglied bist.',
'reason'=>'Änderungsgrund',
'revert_post'=>'Zu dieser Revision zurücksetzen',
'successfully_rate_posting'=>'Deine Bewertung des Beitrags wurde angenommen.',
'time_limit_exceeded_for_edit'=>'Du darfst diesen Beitrag nicht ändern, da er bereits zu alt ist.',
'version_by'=>'Version von',
'your_posting_has_been_filtered_as_spam'=>'Deine Nachricht wurde von unserem Filtersystem als Unerwünscht ("Spam") erkannt.',
'you_cannot_rate_yourself'=>'Du darfst deine eigenen Beiträge nicht bewerten!',
'you_cannot_select_this_prefix'=>'Du bist nicht berechtigt diesen Beitragpräfix zu verwenden!',
'you_have_already_rated'=>'Du hast bei diesem Beitrag bereits abgestimmt!'
);
?>

==> larus_board-1.1.2.zip: larus_board-1.1.2/lb_private/lang/de/post.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'back_to_edit_form'=>'Zurück zum Änderungsformular',
'bbcode_button_anchor'=>'Du kannst einen Anker in deinem Beitrag setzen und diesen verlinken',
'bbcode_button_bold'=>'Wähle den Text aus und klicke hier, um ihn fett zu machen',
'bbcode_button_code'=>'Wähle den Text aus und klicke hier, um ihn als Quellcode zu markieren',
'bbcode_button_embed'=>'Klicke hier, um eine externe URL einzubetten (häufig Multimedia)',
'bbcode_button_format'=>'Klicke hier, wähle dann deinen Text aus und weise ihm Spezialformatierungen zu',
'bbcode_button_img'=>'Klicke hier, um ein externes Bild einzufügen',
'bbcode_button_italic'=>'Wähle den Text aus und klicke hier, um ihn kursiv zu setzen',
'bbcode_button_link'=>'Mit dieser Option kannst du einen anderen Beitrag verlinken oder einen deiner Anker',
'bbcode_button_mail'=>'Klicke hier, um eine E-Mail Adresse anzugeben',
'bbcode_button_notice'=>'Priviligierte Benutzer können einen Absatz hervorheben',
'bbcode_button_quote'=>'Wähle den Text aus und klicke hier, um ihn als Zitat zu markieren.',
'bbcode_button_strikethrough'=>'Wähle den Text aus und klicke hier, um ihn durchzustreichen',
'bbcode_button_underline'=>'Wähle den Text aus und klicke hier, um ihn zu unterstreichen',
'bbcode_button_url'=>'Klicke hier, um eine externe URL anzulegen',
'cannot_reply_as_topic_is_closed'=>'Du kannst nicht auf ein geschlossenes Thema antworten!',
'compare_posts'=>'Beiträge vergleichen',
'compare_selected_revisions'=>'Ausgewählte Revisionen vergleichen',
'current_revision'=>'Aktuelle Version',
'edited_because'=>'Wurde geändert wegen',
'edit_posting'=>'Beitrag ändern',
'explain_message'=>'Deine Nachricht enthält den eigentlichen Text. Hier kannst du diskutieren, antworten, fragen und alles andere.',
'explain_post_acl'=>'Du kannst dem Thema eine Zugriffsbeschränkung auferlegen. Nur Benutzer, die den Regeln entsprechen, können dieses lesen.',
'explain_post_user'=>'Du kannst den Benutzernamen des Beitrages anpassen.',
'explain_post_weight'=>'Je höher das "Gewicht" des Beitrages ist, desto eher wird er gelistet. Deine höchste Einstellung wird durch deine Benutzergruppe vorgegeben.',
'explain_reason'=>'Du kannst hier die Gründe angeben warum du den Beitrag geändert hast. Halte ihn kurz und knackig.',
'explain_subject'=>'Ein Betreff fasst dein Anliegen in wenigen Worten zusammen. Falls Präfixe vorhanden sind, kannst du ihn damit fluggs einer Kategorie zuweisen.',
'explain_tags'=>'Du kannst einem Beitrag Stichwörter zuweisen, um diesen zu beschreiben. Diese werden benutzt, um Beiträge zu gruppieren, welche dieselben aufweisen und so ein einfaches Auffinden ermöglichen. Trenne mehrere Wörter mit einem Komma. Schreibst du zum Beispiel über köstliche Bananen, kannst du die Stichwörter "banane,lecker,frucht,essen" benutzen.',
'invalid_username_on_edit'=>'Du hast versucht einen ungültigen Benutzernamen für diesen Beitrag anzugeben.',
'is_approved_by_default'=>'Der Beitrag ist standardmäßig sofort sichtbar.',
'is_hidden_by_default'=>'Der Beitrag benötigt eine Freigabe bevor er sichtbar wird.',
'listing_all_previous_versions'=>'Dies sind die vergangenen Versionen des Beitrages',
'new_reply'=>'Neue Antwort',
'new_reply_successfully_posted'=>'Deine Antwort wurde dem Thema hinzugefügt.',
'new_topic'=>'Neues Thema',
'new_topic_successfully_posted'=>'Dein Thema wurde dem Forum hinzugefügt.',
'not_allowed_to_access_the_topic'=>'Du hast keinen Zugriff auf das Thema, dem du antworten möchtest!',
'not_allowed_to_submit_repeated_posting'=>'Du kannst keinen weiteren Beitrag schreiben, da der letzte bereits von dir ist!',
'posting_has_been_deleted'=>'Dieser Beitrag wurde gelöscht.',
'posting_has_been_edited'=>'Dieser Beitrag wurde geändert.',
'post_acl'=>'Zugriffsbeschränkung',
'post_source'=>'Quell-Beitrag',
'post_target'=>'Ziel-Beitrag',
'post_weight'=>'Gewicht',
'quote_hint'=>'Falls du eine Nachricht zitierst, bitte beschränke dich auf das wesentliche.',
'rate_disallowed_by_being_too_quiet'=>'Du darfst noch keine Beiträge bewerten, da du selber zu wenige verfasst hast!',
'rate_disallowed_by_short_membership'=>'Du darfst noch keine Beiträge bewerten, da du noch nicht lange genug Mitglied bist.',
'reason'=>'Änderungsgrund',
'revert_post'=>'Zu dieser Revision zurücksetzen',
'successfully_rate_posting'=>'Deine Bewertung des Beitrags wurde angenommen.',
'time_limit_exceeded_for_edit'=>'Du darfst diesen Beitrag nicht ändern, da er bereits zu alt ist.',
'version_by'=>'Version von',
'your_posting_has_been_filtered_as_spam'=>'Deine Nachricht wurde von unserem Filtersystem als Unerwünscht ("Spam") erkannt.',
'you_cannot_rate_yourself'=>'Du darfst deine eigenen Beiträge nicht bewerten!',
'you_cannot_select_this_prefix'=>'Du bist nicht berechtigt diesen Beitragpräfix zu verwenden!',
'you_have_already_rated'=>'Du hast bei diesem Beitrag bereits abgestimmt!'
);
?>
